==> handwritingprocessing-0.0.9.tar.gz: lib/handwritingprocessing.dart <==
import 'dart:async';
import 'dart:collection';
import 'dart:typed_data';

import 'package:flutter/services.dart';

const blackWriteTitle = ['默认', '深色背景', '深灰色', '普通', '浅灰色背景', '浅色背景', '白色背景'];
const removalRedTitle = ['默认', '浅红', '红色', '普通', '大红', '深红', '红褐'];
const removalBlueTitle = ['默认', '浅蓝', '天蓝', '蓝色', '普通', '深蓝', '蓝黑'];

const blackWriteVals = [1000, 5, 11, 19, 30, 42, 55];
const removalRedVals = [20, 5, 9, 13, 30, 42, 55];
const removalBlueVals = [5, 3, 9, 19, 30, 42, 55];

class Handwritingprocessing {
  static const MethodChannel _channel =
      const MethodChannel('handwritingprocessing');

  static Future<String> get version async {
    final String version = await _channel.invokeMethod('version');
    return version;
  }

  static Future<dynamic> inRange(Uint8List byteData, double minh, double mins,
      double minv, double maxh, double maxs, double maxv) async {
    /// Variable to store operation result
    final dynamic result = await _channel.invokeMethod('inRange', {
      'byteData': byteData,
      'minh': minh,
      'mins': mins,
      'minv': minv,
      'maxh': maxh,
      'maxs': maxs,
      'maxv': maxv
    });
    return result;
  }

  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  static Future<dynamic> handwriting(Uint8List byteData, int type,
      {blackWriteIndex = 0, removalRedIndex = 0, removalBlueIndex = 0}) async {
    /// Variable to store operation result
    final dynamic result = await _channel.invokeMethod('handwriting', {
      'byteData': byteData,
      'type': type,
      'blackWriteVal': blackWriteVals[blackWriteIndex],
      'removalRedVal': removalRedVals[removalRedIndex],
      'removalBlueVal': removalBlueVals[removalBlueIndex],
    });
    return result;
  }

  static Future<dynamic> blackWrite(Uint8List byteData) async {
    final dynamic result =
        await _channel.invokeMethod('blackWrite', {'byteData': byteData});
    return result;
  }
}

==> handwritingprocessing-0.0.10.tar.gz: lib/handwritingprocessing.dart <==
import 'dart:async';
import 'dart:collection';
import 'dart:typed_data';

import 'package:flutter/services.dart';

const blackWriteTitle = ['默认', '深色背景', '深灰色', '普通', '浅灰色背景', '浅色背景', '白色背景'];
const removalRedTitle = ['默认', '红褐', '深红', '普通', '红色', '大红', '浅红'];
const removalBlueTitle = ['默认', '蓝黑', '深蓝', '普通', '蓝色', '天蓝', '浅蓝'];

const blackWriteVals = [1000, 5, 11, 19, 30, 42, 55];
const removalRedVals = [20, 5, 9, 13, 30, 42, 55];
const removalBlueVals = [5, 3, 9, 19, 30, 42, 55];

class Handwritingprocessing {
  static const MethodChannel _channel =
      const MethodChannel('handwritingprocessing');

  static Future<String> get version async {
    final String version = await _channel.invokeMethod('version');
    return version;
  }

  static Future<dynamic> inRange(Uint8List byteData, double minh, double mins,
      double minv, double maxh, double maxs, double maxv) async {
    /// Variable to store operation result
    final dynamic result = await _channel.invokeMethod('inRange', {
      'byteData': byteData,
      'minh': minh,
      'mins': mins,
      'minv': minv,
      'maxh': maxh,
      'maxs': maxs,
      'maxv': maxv
    });
    return result;
  }

  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  ///@type B0000黑白，B0001去红，B0010去蓝，B0011去红蓝
  static Future<dynamic> handwriting(Uint8List byteData, int type,
      {blackWriteIndex = 0, removalRedIndex = 0, removalBlueIndex = 0}) async {
    /// Variable to store operation result
    final dynamic result = await _channel.invokeMethod('handwriting', {
      'byteData': byteData,
      'type': type,
      'blackWriteVal': blackWriteVals[blackWriteIndex],
      'removalRedVal': removalRedVals[removalRedIndex],
      'removalBlueVal': removalBlueVals[removalBlueIndex],
    });
    return result;
  }

  static Future<dynamic> blackWrite(Uint8List byteData) async {
    final dynamic result =
        await _channel.invokeMethod('blackWrite', {'byteData': byteData});
    return result;
  }
}
